==> atlas3.3.7.tgz: ATLAS/include/contrib/camm_strat.h <==
#include "camm_util.h"

#define p1_1x4_3(a_) \
      pla(SS(SS(a_,NR),NR),ax,2) \
      pm(0,1) \
      pa(1,5) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,1) \
      pm(0,2) \
      pa(2,6) \
      pla(SS(a_,RS4),ax,2) \
      pm(0,1) \
      pa(1,7) \
      pla(SS(a_,RS4),bx,0) \
      pla(SS(SS(a_,NR),RS4),ax,1) \
      pm(0,2) \
      pa(2,4) 
#define lp1x4_3(a_) \
      pla(a_,bx,0) \
      pla(a_,ax,2) \
      pla(SS(a_,NR),ax,1) \
      pm(0,2) \
      pa(2,4)
#define dp1x4_3(a_) \
      pla(SS(SS(a_,NR),NR),ax,2) \
      pm(0,1) \
      pa(1,5) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,1) \
      pm(0,2) \
      pa(2,6) \
      pm(0,1) \
      pa(1,7) 
#define pl1x4_3 RS

#define p1_1x2_3(a_) \
      pm(0,1) \
      pa(1,5) \
      pla(SS(a_,RS4),ax,2) \
      pla(SS(a_,RS4),bx,0) \
      pla(SS(SS(a_,NR),RS4),ax,1) \
      pm(0,2) \
      pa(2,4) 
#define lp1x2_3(a_) \
      pla(a_,bx,0) \
      pla(a_,ax,2) \
      pla(SS(a_,NR),ax,1) \
      pm(0,2) \
      pa(2,4)
#define dp1x2_3(a_) \
      pm(0,1) \
      pa(1,5)
#define pl1x2_3 RS

#define p1_1x1_3(a_) \
      pla(SS(a_,RS4),bx,0) \
      pla(SS(SS(a_,NR),RS4),ax,1) \
      pm(0,2) \
      pa(2,4) 
#define lp1x1_3(a_) \
      pla(a_,bx,0) \
      pla(a_,ax,2) \
      pm(0,2) \
      pa(2,4)
#define dp1x1_3(a_) 
#define pl1x1_3 RS


#define p1_1x4_2(a_)  \
      pmm(SS(SS(a_,NR),NR),ax,2) \
      pa(0,4) \
      pla(SS(a_,RS4),bx,0) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,3) \
      pa(1,5) \
      pa(2,6) \
      pc(0,2) \
      pmm(SS(a_,RS4),ax,0) \
      pa(3,7) \
      pla(SS(a_,RS4),bx,1) \
      pc(1,3) \
      pmm(SS(SS(a_,RS4),NR),ax,1) 
#define lp1x4_2(a_) \
      pla(a_,bx,0) \
      pla(a_,bx,1) \
      pc(0,2) \
      pc(1,3) \
      pmm(a_,ax,0) \
      pmm(SS(a_,NR),ax,1)      
#define dp1x4_2(a_) \
      pmm(SS(SS(a_,NR),NR),ax,2) \
      pa(0,4) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,3) \
      pa(1,5) \
      pa(2,6) \
      pa(3,7) 
#define pl_1x4_2 RS

      
#define p1_1x2_2(a_)  \
      pa(0,4) \
      pla(SS(a_,RS4),bx,0) \
      pa(1,5) \
      pc(0,2) \
      pmm(SS(a_,RS4),ax,0) \
      pla(SS(a_,RS4),bx,1) \
      pc(1,3) \
      pmm(SS(SS(a_,RS4),NR),ax,1) 
#define lp1x4_2(a_) \
      pla(a_,bx,0) \
      pla(a_,bx,1) \
      pc(0,2) \
      pc(1,3) \
      pmm(a_,ax,0) \
      pmm(SS(a_,NR),ax,1)      
#define dp1x4_2(a_) \
      pmm(SS(SS(a_,NR),NR),ax,2) \
      pa(0,4) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,3) \
      pa(1,5) \
      pa(2,6) \
      pa(3,7) 
#define pl_1x4_2 RS

      
#define p1_1x4_2(a_)  \
      pmm(SS(SS(a_,NR),NR),ax,2) \
      pa(0,4) \
      pla(SS(a_,RS4),bx,0) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,3) \
      pa(1,5) \
      pa(2,6) \
      pc(0,2) \
      pmm(SS(a_,RS4),ax,0) \
      pa(3,7) \
      pla(SS(a_,RS4),bx,1) \
      pc(1,3) \
      pmm(SS(SS(a_,RS4),NR),ax,1) 
#define lp1x4_2(a_) \
      pla(a_,bx,0) \
      pla(a_,bx,1) \
      pc(0,2) \
      pc(1,3) \
      pmm(a_,ax,0) \
      pmm(SS(a_,NR),ax,1)      
#define dp1x4_2(a_) \
      pmm(SS(SS(a_,NR),NR),ax,2) \
      pa(0,4) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,3) \
      pa(1,5) \
      pa(2,6) \
      pa(3,7) 
#define pl_1x4_2 RS

      
#define p1_4(a_,b_) \
      pm(0,2) \
      pa(1,4) \
      pla(SS(SS(a_,NR),NR),ax,1) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,3) \
      pm(0,1) \
      pa(2,5) \
      pm(0,3) \
      pa(1,6) \
      pla(SS(a_,RS4),bx,0) \
      pla(SS(a_,RS4),ax,1) \
      pla(SS(SS(a_,NR),RS4),ax,2) \
      pm(0,1) \
      pa(3,7) 
#define lp4(a_) \
      pla(a_,bx,0) \
      pla(a_,ax,1) \
      pla(SS(a_,NR),ax,2) \
      pm(0,1) 
#define dp4(a_) \
      pm(0,2) \
      pa(1,4) \
      pla(SS(SS(a_,NR),NR),ax,1) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,3) \
      pm(0,1) \
      pa(2,5) \
      pm(0,3) \
      pa(1,6) \
      pa(3,7) 
#define pl4 RS


#define p1_6(a_,b_) \
      pm(0,2) \
      pa(1,5) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,1) \
      pla(SS(a_,RS4),ax,3) \
      pm(0,1) \
      pa(2,6) \
      pla(SS(SS(SS(a_,NR),NR),RS4),ax,2) \
      pla(SS(a_,RS4),bx,0) \
      pm(0,3) \
      pa(1,7) \
      pla(SS(SS(a_,NR),RS4),ax,1) \
      pm(0,1) \
      pa(3,4) 
#define lp6(a_) \
      pla(a_,bx,0) \
      pla(a_,ax,3) \
      pla(SS(a_,NR),ax,1) \
      pla(SS(SS(a_,NR),NR),ax,2) \
      pm(0,3) \
      pa(3,4) \
      pm(0,1)
#define dp6(a_) \
      pm(0,2) \
      pa(1,5) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,1) \
      pm(0,1) \
      pa(2,6) \
      pa(1,7) 
#define pl6 RS




#define p1_7(a_,b_,c_,d_,e_) \
      pla(SS(SS(a_,NR),NR),ax,c_) \
      pm(0,d_) \
      pa(e_,4) \
      pm(0,c_) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,0) \
      pa(d_,5) \
      pla(SS(a_,RS4),ax,d_) \
      pa(0,7) \
      pla(SS(a_,RS4),bx,0) \
      pa(c_,6) \
      pla(SS(SS(a_,NR),RS4),ax,c_) \
      pm(0,d_) 
#define lp7(a_,c_,d_,e_) \
      pla(a_,bx,0) \
      pla(a_,ax,d_) \
      pla(SS(a_,NR),ax,c_) \
      pm(0,d_)

#define dp7(a_,c_,d_,e_) \
      pla(SS(SS(a_,NR),NR),ax,c_) \
      pm(0,d_) \
      pa(e_,4) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,e_) \
      pm(0,c_) \
      pa(d_,5) \
      pm(0,e_) \
      pa(c_,6) \
      pa(e_,7)
#define pl7 RS




#define p1_5(a_,b_) \
      pla(a_,bx,0) \
      pla(a_,ax,1) \
      pla(SS(a_,NR),ax,2) \
      pla(SS(SS(a_,NR),NR),ax,3) \
      pm(0,1) \
      pm(0,2) \
      pm(0,3) \
      pa(1,4) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,1) \
      pa(2,5) \
      pm(1,0) \
      pa(3,6) \
      pa(0,7)

#define lp5(a_)
#define dp5(a_) 
#define pl5 0

#define p1_8(a_,b_) \
      pla(a_,bx,0) \
      pla(a_,ax,1) \
      pm(0,1) \
      pa(1,4) \
      pla(SS(a_,NR),ax,2) \
      pm(0,2) \
      pa(2,5) \
      pla(SS(SS(a_,NR),NR),ax,3) \
      pm(0,3) \
      pa(3,6) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,1) \
      pm(0,1) \
      pa(1,7)

#define lp8(a_)
#define dp8(a_) 
#define pl8 0

#define p1_9(a_,b_) \
      pla(a_,bx,0) \
      pla(a_,ax,1) \
      pm(0,1) \
      pa(1,4) \
      pla(SS(a_,NR),ax,2) \
      pm(0,2) \
      pa(2,5) \
      pla(SS(SS(a_,NR),NR),ax,3) \
      pm(0,3) \
      pa(3,6) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,0) \
      pa(0,7)

#define lp9(a_) 
#define dp9(a_) 
#define pl9 0

#define p1_10(a_,b_) \
      pla(a_,ax,1) \
      pla(a_,bx,0) \
      pm(0,1) \
      pa(1,4) \
      pla(SS(a_,NR),ax,2) \
      pm(0,2) \
      pa(2,5) \
      pla(SS(SS(a_,NR),NR),ax,1) \
      pm(0,1) \
      pa(1,6) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,0) \
      pa(0,7) 

#define lp10(a_) 
#define dp10(a_)
#define pl10 0


#define p1_1x4_1(a_) \
      pla(a_,ax,1) \
      pla(a_,bx,0) \
      pm(0,1) \
      pa(1,4) \
      pla(SS(a_,NR),ax,2) \
      pm(0,2) \
      pa(2,5) \
      pla(SS(a_,SS(NR,NR)),ax,1) \
      pm(0,1) \
      pa(1,6) \
      pmm(SS(a_,SS(NR,SS(NR,NR))),ax,0) \
      pa(0,7) 

#define p1_2_1x4_1(a_) \
      px(0) \
      pld(a_,bx,0)  \
      px(1) \
      pld(a_,ax,1) \
      pm(0,1) \
      pa(1,4) \
      px(2) \
      pld(SS(a_,NR),ax,2) \
      pm(0,2) \
      pa(2,5) \
      px(1) \
      pld(SS(a_,SS(NR,NR)),ax,1) \
      pm(0,1) \
      pa(1,6) \
      px(2) \
      pld(SS(a_,SS(NR,SS(NR,NR))),ax,2) \
      pm(0,2) \
      pa(2,7) 
                    

#define p1_4_1x4_1(a_) \
      pls(a_,bx,0)  \
      pls(a_,ax,1) \
      pmsr(0,1) \
      pasr(1,4) \
      pls(SS(a_,NR),ax,2) \
      pmsr(0,2) \
      pasr(2,5) \
      pls(SS(a_,SS(NR,NR)),ax,1) \
      pmsr(0,1) \
      pasr(1,6) \
      pls(SS(a_,SS(NR,SS(NR,NR))),ax,2) \
      pmsr(2,0) \
      pasr(0,2) 

#define lp1x4_1(a_) 
#define dp1x4_1(a_) 
#define pl1x4_1 0

#define p1_1x2_1(a_) \
      pla(a_,ax,1) \
      pla(a_,bx,0) \
      pm(0,1) \
      pa(1,4) \
      pla(SS(a_,NR),ax,2) \
      pm(0,2) \
      pa(2,5) 

#define p1_2_1x2_1(a_) \
      px(0) \
      pld(a_,bx,0)  \
      px(1) \
      pld(a_,ax,1) \
      pm(0,1) \
      pa(1,4) \
      px(2) \
      pld(SS(a_,NR),ax,2) \
      pm(0,2) \
      pa(2,5)
                    

#define p1_4_1x2_1(a_) \
      pls(a_,bx,0)  \
      pls(a_,ax,1) \
      pmsr(0,1) \
      pasr(1,4) \
      pls(SS(a_,NR),ax,2) \
      pmsr(0,2) \
      pasr(2,5)

#define lp1x2_1(a_) 
#define dp1x2_1(a_) 
#define pl1x2_1 0


#define p1_1x1_1(a_) \
      pla(a_,ax,1) \
      pla(a_,bx,0) \
      pm(0,1) \
      pa(1,4)

#define p1_2_1x1_1(a_) \
      px(0) \
      pld(a_,bx,0)  \
      px(1) \
      pld(a_,ax,1) \
      pm(0,1) \
      pa(1,4)
                    

#define p1_4_1x1_1(a_) \
      pls(a_,bx,0)  \
      pls(a_,ax,1) \
      pmsr(0,1) \
      pasr(1,4)

#define lp1x1_1(a_) 
#define dp1x1_1(a_) 
#define pl1x1_1 0

==> atlas3.5.9.tgz: ATLAS/include/contrib/camm_strat.h <==
#include "camm_util.h"

#undef p1_1x4_3
#define p1_1x4_3(a_) \
      pla(SS(SS(a_,NR),NR),ax,2) \
      pm(0,1) \
      pa(1,5) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,1) \
      pm(0,2) \
      pa(2,6) \
      pla(SS(a_,RS4),ax,2) \
      pm(0,1) \
      pa(1,7) \
      pla(SS(a_,RS4),bx,0) \
      pla(SS(SS(a_,NR),RS4),ax,1) \
      pm(0,2) \
      pa(2,4) 
#undef lp1x4_3
#define lp1x4_3(a_) \
      pla(a_,bx,0) \
      pla(a_,ax,2) \
      pla(SS(a_,NR),ax,1) \
      pm(0,2) \
      pa(2,4)
#undef dp1x4_3
#define dp1x4_3(a_) \
      pla(SS(SS(a_,NR),NR),ax,2) \
      pm(0,1) \
      pa(1,5) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,1) \
      pm(0,2) \
      pa(2,6) \
      pm(0,1) \
      pa(1,7) 
#undef pl1x4_3
#define pl1x4_3 RS

#undef p1_1x2_3
#define p1_1x2_3(a_) \
      pm(0,1) \
      pa(1,5) \
      pla(SS(a_,RS4),ax,2) \
      pla(SS(a_,RS4),bx,0) \
      pla(SS(SS(a_,NR),RS4),ax,1) \
      pm(0,2) \
      pa(2,4) 
#undef lp1x2_3
#define lp1x2_3(a_) \
      pla(a_,bx,0) \
      pla(a_,ax,2) \
      pla(SS(a_,NR),ax,1) \
      pm(0,2) \
      pa(2,4)
#undef dp1x2_3
#define dp1x2_3(a_) \
      pm(0,1) \
      pa(1,5)
#undef pl1x2_3
#define pl1x2_3 RS


#undef p1_1x1_3
#define p1_1x1_3(a_) \
      pla(SS(a_,RS4),bx,0) \
      pla(SS(SS(a_,NR),RS4),ax,1) \
      pm(0,2) \
      pa(2,4) 
#undef lp1x1_3
#define lp1x1_3(a_) \
      pla(a_,bx,0) \
      pla(a_,ax,2) \
      pm(0,2) \
      pa(2,4)
#undef dp1x1_3
#define dp1x1_3(a_) 
#undef pl1x1_3 
#define pl1x1_3 RS


#undef p1_1x4_2
#define p1_1x4_2(a_)  \
      pmm(SS(SS(a_,NR),NR),ax,2) \
      pa(0,4) \
      pla(SS(a_,RS4),bx,0) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,3) \
      pa(1,5) \
      pa(2,6) \
      pc(0,2) \
      pmm(SS(a_,RS4),ax,0) \
      pa(3,7) \
      pla(SS(a_,RS4),bx,1) \
      pc(1,3) \
      pmm(SS(SS(a_,RS4),NR),ax,1) 
#undef lp1x4_2
#define lp1x4_2(a_) \
      pla(a_,bx,0) \
      pla(a_,bx,1) \
      pc(0,2) \
      pc(1,3) \
      pmm(a_,ax,0) \
      pmm(SS(a_,NR),ax,1)      
#undef dp1x4_2
#define dp1x4_2(a_) \
      pmm(SS(SS(a_,NR),NR),ax,2) \
      pa(0,4) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,3) \
      pa(1,5) \
      pa(2,6) \
      pa(3,7) 
#undef pl_1x4_2
#define pl_1x4_2 RS

      
#undef p1_1x2_2
#define p1_1x2_2(a_)  \
      pa(0,4) \
      pla(SS(a_,RS4),bx,0) \
      pa(1,5) \
      pc(0,2) \
      pmm(SS(a_,RS4),ax,0) \
      pla(SS(a_,RS4),bx,1) \
      pc(1,3) \
      pmm(SS(SS(a_,RS4),NR),ax,1) 
#undef lp1x4_2
#define lp1x4_2(a_) \
      pla(a_,bx,0) \
      pla(a_,bx,1) \
      pc(0,2) \
      pc(1,3) \
      pmm(a_,ax,0) \
      pmm(SS(a_,NR),ax,1)      
#undef dp1x4_2
#define dp1x4_2(a_) \
      pmm(SS(SS(a_,NR),NR),ax,2) \
      pa(0,4) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,3) \
      pa(1,5) \
      pa(2,6) \
      pa(3,7) 
#undef pl_1x4_2
#define pl_1x4_2 RS

      
#undef p1_1x4_2
#define p1_1x4_2(a_)  \
      pmm(SS(SS(a_,NR),NR),ax,2) \
      pa(0,4) \
      pla(SS(a_,RS4),bx,0) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,3) \
      pa(1,5) \
      pa(2,6) \
      pc(0,2) \
      pmm(SS(a_,RS4),ax,0) \
      pa(3,7) \
      pla(SS(a_,RS4),bx,1) \
      pc(1,3) \
      pmm(SS(SS(a_,RS4),NR),ax,1) 
#undef lp1x4_2
#define lp1x4_2(a_) \
      pla(a_,bx,0) \
      pla(a_,bx,1) \
      pc(0,2) \
      pc(1,3) \
      pmm(a_,ax,0) \
      pmm(SS(a_,NR),ax,1)      
#undef dp1x4_2
#define dp1x4_2(a_) \
      pmm(SS(SS(a_,NR),NR),ax,2) \
      pa(0,4) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,3) \
      pa(1,5) \
      pa(2,6) \
      pa(3,7) 
#undef pl_1x4_2
#define pl_1x4_2 RS

      
#undef p1_4
#define p1_4(a_,b_) \
      pm(0,2) \
      pa(1,4) \
      pla(SS(SS(a_,NR),NR),ax,1) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,3) \
      pm(0,1) \
      pa(2,5) \
      pm(0,3) \
      pa(1,6) \
      pla(SS(a_,RS4),bx,0) \
      pla(SS(a_,RS4),ax,1) \
      pla(SS(SS(a_,NR),RS4),ax,2) \
      pm(0,1) \
      pa(3,7) 
#undef lp4
#define lp4(a_) \
      pla(a_,bx,0) \
      pla(a_,ax,1) \
      pla(SS(a_,NR),ax,2) \
      pm(0,1) 
#undef dp4
#define dp4(a_) \
      pm(0,2) \
      pa(1,4) \
      pla(SS(SS(a_,NR),NR),ax,1) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,3) \
      pm(0,1) \
      pa(2,5) \
      pm(0,3) \
      pa(1,6) \
      pa(3,7) 
#undef pl4
#define pl4 RS


#undef p1_6
#define p1_6(a_,b_) \
      pm(0,2) \
      pa(1,5) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,1) \
      pla(SS(a_,RS4),ax,3) \
      pm(0,1) \
      pa(2,6) \
      pla(SS(SS(SS(a_,NR),NR),RS4),ax,2) \
      pla(SS(a_,RS4),bx,0) \
      pm(0,3) \
      pa(1,7) \
      pla(SS(SS(a_,NR),RS4),ax,1) \
      pm(0,1) \
      pa(3,4) 
#undef lp6
#define lp6(a_) \
      pla(a_,bx,0) \
      pla(a_,ax,3) \
      pla(SS(a_,NR),ax,1) \
      pla(SS(SS(a_,NR),NR),ax,2) \
      pm(0,3) \
      pa(3,4) \
      pm(0,1)
#undef dp6
#define dp6(a_) \
      pm(0,2) \
      pa(1,5) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,1) \
      pm(0,1) \
      pa(2,6) \
      pa(1,7) 
#undef pl6
#define pl6 RS

#undef p1_7
#define p1_7(a_,b_,c_,d_,e_) \
      pla(SS(SS(a_,NR),NR),ax,c_) \
      pm(0,d_) \
      pa(e_,4) \
      pm(0,c_) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,0) \
      pa(d_,5) \
      pla(SS(a_,RS4),ax,d_) \
      pa(0,7) \
      pla(SS(a_,RS4),bx,0) \
      pa(c_,6) \
      pla(SS(SS(a_,NR),RS4),ax,c_) \
      pm(0,d_) 
#undef lp7
#define lp7(a_,c_,d_,e_) \
      pla(a_,bx,0) \
      pla(a_,ax,d_) \
      pla(SS(a_,NR),ax,c_) \
      pm(0,d_)
#undef dp7
#define dp7(a_,c_,d_,e_) \
      pla(SS(SS(a_,NR),NR),ax,c_) \
      pm(0,d_) \
      pa(e_,4) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,e_) \
      pm(0,c_) \
      pa(d_,5) \
      pm(0,e_) \
      pa(c_,6) \
      pa(e_,7)
#undef pl7
#define pl7 RS

#undef p1_5
#define p1_5(a_,b_) \
      pla(a_,bx,0) \
      pla(a_,ax,1) \
      pla(SS(a_,NR),ax,2) \
      pla(SS(SS(a_,NR),NR),ax,3) \
      pm(0,1) \
      pm(0,2) \
      pm(0,3) \
      pa(1,4) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,1) \
      pa(2,5) \
      pm(1,0) \
      pa(3,6) \
      pa(0,7)
#undef lp5
#define lp5(a_)
#undef dp5
#define dp5(a_) 
#undef pl5
#define pl5 0


#undef p1_8
#define p1_8(a_,b_) \
      pla(a_,bx,0) \
      pla(a_,ax,1) \
      pm(0,1) \
      pa(1,4) \
      pla(SS(a_,NR),ax,2) \
      pm(0,2) \
      pa(2,5) \
      pla(SS(SS(a_,NR),NR),ax,3) \
      pm(0,3) \
      pa(3,6) \
      pla(SS(SS(SS(a_,NR),NR),NR),ax,1) \
      pm(0,1) \
      pa(1,7)
#undef lp8
#define lp8(a_)
#undef dp8
#define dp8(a_) 
#undef pl8
#define pl8 0


#undef p1_9
#define p1_9(a_,b_) \
      pla(a_,bx,0) \
      pla(a_,ax,1) \
      pm(0,1) \
      pa(1,4) \
      pla(SS(a_,NR),ax,2) \
      pm(0,2) \
      pa(2,5) \
      pla(SS(SS(a_,NR),NR),ax,3) \
      pm(0,3) \
      pa(3,6) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,0) \
      pa(0,7)
#undef lp9
#define lp9(a_) 
#undef dp9
#define dp9(a_) 
#undef pl9
#define pl9 0


#undef p1_10
#define p1_10(a_,b_) \
      pla(a_,ax,1) \
      pla(a_,bx,0) \
      pm(0,1) \
      pa(1,4) \
      pla(SS(a_,NR),ax,2) \
      pm(0,2) \
      pa(2,5) \
      pla(SS(SS(a_,NR),NR),ax,1) \
      pm(0,1) \
      pa(1,6) \
      pmm(SS(SS(SS(a_,NR),NR),NR),ax,0) \
      pa(0,7) 
#undef lp10
#define lp10(a_) 
#undef dp10
#define dp10(a_)
#undef pl10
#define pl10 0


#undef p1_1x4_1
#define p1_1x4_1(a_) \
      pla(a_,ax,1) \
      pla(a_,bx,0) \
      pm(0,1) \
      pa(1,4) \
      pla(SS(a_,NR),ax,2) \
      pm(0,2) \
      pa(2,5) \
      pla(SS(a_,SS(NR,NR)),ax,1) \
      pm(0,1) \
      pa(1,6) \
      pmm(SS(a_,SS(NR,SS(NR,NR))),ax,0) \
      pa(0,7) 
#undef p1_2_1x4_1
#define p1_2_1x4_1(a_) \
      px(0) \
      pld(a_,bx,0)  \
      px(1) \
      pld(a_,ax,1) \
      pm(0,1) \
      pa(1,4) \
      px(2) \
      pld(SS(a_,NR),ax,2) \
      pm(0,2) \
      pa(2,5) \
      px(1) \
      pld(SS(a_,SS(NR,NR)),ax,1) \
      pm(0,1) \
      pa(1,6) \
      px(2) \
      pld(SS(a_,SS(NR,SS(NR,NR))),ax,2) \
      pm(0,2) \
      pa(2,7) 
#undef p1_4_1x4_1
#define p1_4_1x4_1(a_) \
      pls(a_,bx,0)  \
      pls(a_,ax,1) \
      pmsr(0,1) \
      pasr(1,4) \
      pls(SS(a_,NR),ax,2) \
      pmsr(0,2) \
      pasr(2,5) \
      pls(SS(a_,SS(NR,NR)),ax,1) \
      pmsr(0,1) \
      pasr(1,6) \
      pls(SS(a_,SS(NR,SS(NR,NR))),ax,2) \
      pmsr(2,0) \
      pasr(0,2) 
#undef lp1x4_1
#define lp1x4_1(a_) 
#undef dp1x4_1
#define dp1x4_1(a_) 
#undef pl1x4_1
#define pl1x4_1 0


#undef p1_1x2_1
#define p1_1x2_1(a_) \
      pla(a_,ax,1) \
      pla(a_,bx,0) \
      pm(0,1) \
      pa(1,4) \
      pla(SS(a_,NR),ax,2) \
      pm(0,2) \
      pa(2,5) 
#undef p1_2_1x2_1
#define p1_2_1x2_1(a_) \
      px(0) \
      pld(a_,bx,0)  \
      px(1) \
      pld(a_,ax,1) \
      pm(0,1) \
      pa(1,4) \
      px(2) \
      pld(SS(a_,NR),ax,2) \
      pm(0,2) \
      pa(2,5)
#undef p1_4_1x2_1
#define p1_4_1x2_1(a_) \
      pls(a_,bx,0)  \
      pls(a_,ax,1) \
      pmsr(0,1) \
      pasr(1,4) \
      pls(SS(a_,NR),ax,2) \
      pmsr(0,2) \
      pasr(2,5)
#undef lp1x2_1
#define lp1x2_1(a_) 
#undef dp1x2_1
#define dp1x2_1(a_) 
#undef pl1x2_1
#define pl1x2_1 0


#undef p1_1x1_1
#define p1_1x1_1(a_) \
      pla(a_,ax,1) \
      pla(a_,bx,0) \
      pm(0,1) \
      pa(1,4)
#undef p1_2_1x1_1
#define p1_2_1x1_1(a_) \
      px(0) \
      pld(a_,bx,0)  \
      px(1) \
      pld(a_,ax,1) \
      pm(0,1) \
      pa(1,4)
#undef p1_4_1x1_1
#define p1_4_1x1_1(a_) \
      pls(a_,bx,0)  \
      pls(a_,ax,1) \
      pmsr(0,1) \
      pasr(1,4)
#undef lp1x1_1
#define lp1x1_1(a_) 
#undef dp1x1_1
#define dp1x1_1(a_) 
#undef pl1x1_1
#define pl1x1_1 0
